@@ -27,7 +27,7 @@
 //!    println!("{:?}, line {}",&token,fscan.line_number());
 //!  }
 //!```
-//! The supplied *main.rs* and file *test.c* contain additional usage examples.
+//! The supplied *main.rs* and file *test.c* on github contain additional usage examples.
 
 
 
@@ -351,6 +351,11 @@ impl File_tokenizer
    pub fn line_number(&self)->usize {self.linenum}
    /// returns the current column (character position) on the current line
    pub fn column_number(&self)->usize {self.column}
+   /// returns a copy of the current line being tokenized
+   pub fn current_line<'t>(&'t self)-> String
+   {
+        self.line.borrow().clone()
+   }
 
    /// adds keywords that are to be distinguished from other alphanumeric
    /// tokens.  Keywords are returned as [Keyword] tokens.  Keywords
@@ -569,7 +574,7 @@ impl Iterator for File_tokenizer
        }
        self.column += ind;
        match return_value {
-         Some(Nothing) if self.current_string.len()>0 => {}, // keep looping
+         Some(Nothing) /*if self.current_string.len()>0*/ => {}, // keep looping
          Some(Newline) if !self.keep_newline => {},
          _ => {break;}
        }
@@ -579,10 +584,6 @@ impl Iterator for File_tokenizer
 }//impl Iterator for File_tokenizer
 
 
-// currently cannot recognize string literals that span multiple lines...
-// or multi-line comments (less important)
-
-
 // integrate into RustLr:
 /*
 pub trait Token_translator<AT:Default>
